@@ -11,9 +11,7 @@
 # Short-Description: Check to root file system.
 ### END INIT INFO
 
-# Include /usr/bin in path to find on_ac_power if /usr/ is on the root
-# partition.
-PATH=/usr/bin:/sbin:/bin
+PATH=/sbin:/bin
 FSCK_LOGFILE=/var/log/fsck/checkroot
 [ "$FSCKFIX" ] || FSCKFIX=no
 [ "$SULOGIN" ] || SULOGIN=no
@@ -141,24 +139,6 @@ Will restart in 5 seconds."
 		reboot -f
 	fi
 
-	# See if we're on AC Power.  If not, we're not gonna run our
-	# check.  If on_ac_power (in /usr/) is unavailable, behave as
-	# before and check all file systems needing it.
-	# Disabled AC power check until fsck can be told to only check the
-	# file system if it is corrupt when running on battery. (bug #526398)
-	#	if which on_ac_power >/dev/null 2>&1 && [ "$rootcheck" = yes ]
-	#	then
-	#		on_ac_power >/dev/null 2>&1
-	#		if [ "$?" -eq 1 ]
-	#		then
-	#			log_warning_msg "On battery power, so skipping file system check."
-	#			rootcheck=no
-	#		fi
-	#	fi
-
-	#
-	# See if we want to check the root file system.
-	#
 	FSCKCODE=0
 
 	if [ -e /run/initramfs/fsck-root ]; then
