@@ -27,33 +27,31 @@ do_wait_async_mount() {
 		if [ -f "$file" ]; then
 			while read DEV MTPT FSTYPE OPTS REST; do
 				case "$DEV" in
-				  ""|\#*)
-					continue
-					;;
+					"" | \#*)
+						continue
+						;;
 				esac
 				case "$OPTS" in
-				  noauto|*,noauto|noauto,*|*,noauto,*)
-					continue
-					;;
+					noauto | *,noauto | noauto,* | *,noauto,*)
+						continue
+						;;
 				esac
 				case "$FSTYPE" in
-				  nfs|nfs4|smbfs|cifs|coda|ncp|ncpfs|ceph)
-					;;
-				  *)
-					continue
-					;;
+					nfs | nfs4 | smbfs | cifs | coda | ncp | ncpfs | ceph) ;;
+					*)
+						continue
+						;;
 				esac
 				case "$MTPT" in
-				  /usr/local|/usr/local/*)
-					;;
-				  /usr|/usr/*)
-					waitnfs="$waitnfs $MTPT"
-					;;
-				  /var|/var/*)
-					waitnfs="$waitnfs $MTPT"
-					;;
+					/usr/local | /usr/local/*) ;;
+					/usr | /usr/*)
+						waitnfs="$waitnfs $MTPT"
+						;;
+					/var | /var/*)
+						waitnfs="$waitnfs $MTPT"
+						;;
 				esac
-			done < "$file"
+			done <"$file"
 		fi
 	done
 
@@ -66,7 +64,7 @@ do_wait_async_mount() {
 		while ! mountpoint -q $mountpt; do
 			sleep 0.1
 
-			TIMEOUT=$(( $TIMEOUT - 1 ))
+			TIMEOUT=$((TIMEOUT - 1))
 			if [ $TIMEOUT -le 0 ]; then
 				log_action_end_msg 1
 				break
@@ -80,27 +78,27 @@ do_wait_async_mount() {
 }
 
 case "$1" in
-    start)
-        # Using 'no !=' instead of 'yes =' to make sure async nfs
-        # mounting is the default even without a value in
-        # /etc/default/rcS
-        if [ no != "$ASYNCMOUNTNFS" ] ; then
-                do_wait_async_mount
-        else
-                FROMINITD=yes /etc/network/if-up.d/mountnfs
-        fi
-        ;;
-    restart|reload|force-reload)
-        echo "Error: argument '$1' not supported" >&2
-        exit 3
-        ;;
-    stop|status)
-        # No-op
-        ;;
-    *)
-        echo "Usage: $0 start|stop" >&2
-        exit 3
-        ;;
+	start)
+		# Using 'no !=' instead of 'yes =' to make sure async nfs
+		# mounting is the default even without a value in
+		# /etc/default/rcS
+		if [ no != "$ASYNCMOUNTNFS" ]; then
+			do_wait_async_mount
+		else
+			FROMINITD=yes /etc/network/if-up.d/mountnfs
+		fi
+		;;
+	restart | reload | force-reload)
+		echo "Error: argument '$1' not supported" >&2
+		exit 3
+		;;
+	stop | status)
+		# No-op
+		;;
+	*)
+		echo "Usage: $0 start|stop" >&2
+		exit 3
+		;;
 esac
 
 :
